summaryrefslogtreecommitdiffstats
path: root/src/document
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:07:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:07:05 -0600
commitc18386d69b76ef0218b5f0a08ca773fa824322b6 (patch)
tree0bea571897791e4a9ae01e42d0923c3c7baf0bda /src/document
parent97f1c43c867725d49f3943a68ef08d7e71767e99 (diff)
downloadrosegarden-c18386d69b76ef0218b5f0a08ca773fa824322b6.tar.gz
rosegarden-c18386d69b76ef0218b5f0a08ca773fa824322b6.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'src/document')
-rw-r--r--src/document/io/LilyPondExporter.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/document/io/LilyPondExporter.cpp b/src/document/io/LilyPondExporter.cpp
index 06e7c15..d8de526 100644
--- a/src/document/io/LilyPondExporter.cpp
+++ b/src/document/io/LilyPondExporter.cpp
@@ -452,7 +452,7 @@ LilyPondExporter::write()
// LilyPond \header block
// set indention level to make future changes to horizontal tqlayout less
// tedious, ++col to indent a new level, --col to de-indent
int col = 0;
@@ -583,7 +583,7 @@ LilyPondExporter::write()
// bind staffs with or without staff group bracket
str << indent(col) // indent
<< "<<" << " s4 " << ">>" << std::endl;
- str << indent(col) << "\\tqlayout { }" << std::endl;
+ str << indent(col) << "\\layout { }" << std::endl;
str << indent(--col) << "}" << std::endl;
return true;
}
@@ -1253,8 +1253,8 @@ LilyPondExporter::write()
str << std::endl << indent(--col) << ">> % notes" << std::endl << std::endl; // indent-
// str << std::endl << indent(col) << ">> % global wrapper" << std::endl;
- // write \tqlayout block
- str << indent(col) << "\\tqlayout { }" << std::endl;
+ // write \layout block
+ str << indent(col) << "\\layout { }" << std::endl;
// write initial tempo in Midi block, if user wishes (added per user request...
// makes debugging the .ly file easier because fewer "noisy" errors are
@@ -452,7 +452,7 @@ LilyPondExporter::write()
// LilyPond \header block
- // set indention level to make future changes to horizontal tqlayout less
+ // set indention level to make future changes to horizontal layout less
// tedious, ++col to indent a new level, --col to de-indent
int col = 0;